<?php
/** 
*
* common [Finnish [Fin]]
*
* @package language
* @copyright (c) 2006 phpBB Group 
* @author 2006-11-14 - Lurttinen@phpbbsuomi.com
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

/**
* DO NOT CHANGE
*/
    if (!defined('IN_PHPBB'))
    {
       exit;
    }

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
//
// Some characters you may want to copy&paste: 
// ’ » “ ”
//

$lang = array_merge($lang, array(
	'TRANSLATION_INFO'	=> 'Käännös, Lurttinen, <a href="http://www.phpbbsuomi.com">www.phpbbsuomi.com</a>',
	'DIRECTION'			=> 'ltr',
	'DATE_FORMAT'		=> '|d.m.Y H:i|',
	'USER_LANG'			=> 'fi',

	'1_DAY'			=> '1 päivä',
	'1_MONTH'		=> '1 kuukausi',
	'1_YEAR'		=> '1 vuosi',
	'2_WEEKS'		=> '2 viikkoa',
	'3_MONTHS'		=> '3 kuukautta',
	'6_MONTHS'		=> '6 kuukautta',
	'7_DAYS'		=> '7 päivää',

	'ACCOUNT_ALREADY_ACTIVATED'		=> 'Tunnuksesi on jo aktivoitu',
	'ACCOUNT_DEACTIVATED'			=> 'Käyttäjätunnuksesi on suljettu manuaalisesti ja vain ylläpitäjä voi avata ne uudelleen.',
	'ACCOUNT_NOT_ACTIVATED'			=> 'Tunnuksiasi ei ole aktivoitu',
	'ACP'							=> 'Ylläpidon asetukset',
	'ACTIVE'						=> 'Aktiivinen',
	'ACTIVE_ERROR'					=> 'Olet antanut vahvistamattoman tunnuksen. Vahvista tunnuksesi ja yritä uudelleen. Mikäli ongelmat jatkuvat. Ota yhteyttä sivuston ylläpitäjiin.',
	'ADMINISTRATOR'					=> 'Ylläpitäjä',
	'ADMINISTRATORS'				=> 'Ylläpitäjät',
	'AGE'							=> 'Ikä',
	'AIM'							=> 'AIM',
	'ALLOWED'						=> 'Sallittu',
	'ALL_FILES'						=> 'Kaikki tiedostot',
	'ALL_FORUMS'					=> 'Kaikki keskustelualueet',
	'ALL_MESSAGES'					=> 'Kaikki viestit',
	'ALL_POSTS'						=> 'Kaikki viestit',
	'ALL_TIMES'						=> 'Kaikki ajat ovat %1$s %2$s',
	'ALL_TOPICS'					=> 'Kaikki viestiketjut',
	'AND'							=> 'ja',
	'ARE_WATCHING_FORUM'			=> 'Olet asettanut seurantaan tälle keskustelualueelle tulevat uudet viestit.',
	'ARE_WATCHING_TOPIC'			=> 'Olet asettanut seurantaan tähän viestiketjuun tulevat uudet viestit.',
	'ASCENDING'						=> 'Nouseva',
	'ATTACHMENTS'					=> 'Liitteet',
	'ATTACHED_IMAGE_NOT_IMAGE'		=> 'Yritit liittää epäkelvon kuvatiedoston.',
	'AUTHOR'						=> 'Kirjoittaja',
	'AUTH_NO_PROFILE_CREATED'		=> 'Käyttäjän profiilin luominen epäonnistui',
	'AVATAR_DISALLOWED_CONTENT'		=> 'Tiedoston siirto hylättiin, koska se tunnistettiin mahdolliseksi hyökkäykseksi.',
	'AVATAR_DISALLOWED_EXTENSION'	=> 'Tiedoston tunniste %s ei ole sallittu',
	'AVATAR_EMPTY_REMOTE_DATA'		=> 'Avataria ei voitu siirtää palvelimelle. Tiedostossa on epäkelpoa dataa tai se on korruptoitunut',
	'AVATAR_EMPTY_FILEUPLOAD'		=> 'Siirtämäsi avatar-tiedosto on tyhjä.',
	'AVATAR_INVALID_FILENAME'		=> '%s ei ole sallittu tiedostonimi',
	'AVATAR_NOT_UPLOADED'			=> 'Avataria ei voitu siirtää palvelimelle.',
	'AVATAR_NO_SIZE'				=> 'En onnistunut lukemaan linkitetyn avatarin korkeutta ja leveyttä. Ole hyvä ja lisää ne manuaalisesti.',
	'AVATAR_PARTIAL_UPLOAD'			=> 'Tiedosto siirrettiin vain osittain',
	'AVATAR_PHP_SIZE_NA'			=> 'Avatar-tiedoston koko on liian suuri.<br />En voinut päätellä maksimikokoa, jonka PHP on määritellyt php.ini-tiedostossa.',
	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Avatar-tiedoston koko on liian suuri. Suurin sallittu koko on %1$d %2$s.<br />Huomaa, että tämä asetetaan php.ini-tiedostossa ja sitä ei voi ohittaa.',
	'AVATAR_URL_INVALID'			=> 'Antamasi linkki on epäkelpo.',
	'AVATAR_URL_NOT_FOUND'			=> 'Tiedostoa ei löydy.',
	'AVATAR_WRONG_FILESIZE'			=> 'Avatar-tiedoston koko täytyy olla välilä 0 ja %1d %2s.',
	'AVATAR_WRONG_SIZE'				=> 'Avatarin täytyy olla vähintään %1$d kuvapistettä leveä, %2$d kuvapistettä korkea ja enimmillään %3$d kuvapistettä leveä ja %4$d kuvapistettä korkea. Lähettämäsi avatar on %5$d kuvapistettä leveä ja %6$d kuvapistettä korkea.',

	'BACK_TO_TOP'			=> 'Ylös',
	'BACK_TO_PREV'			=> 'Takaisin edelliselle sivulle',
	'BAN_TRIGGERED_BY_EMAIL'=> 'Tämä porttikielto on annettu sähköpostiosoitteellesi.',
	'BAN_TRIGGERED_BY_IP'	=> 'Tämä porttikielto on annettu IP-osoitteellesi.',
	'BAN_TRIGGERED_BY_USER'	=> 'Tämä porttikielto on annettu käyttäjätunnuksellesi.',
	'BBCODE_GUIDE'			=> 'BBCode-opas',
	'BCC'					=> 'BCC',
	'BIRTHDAYS'				=> 'Syntymäpäivät',
	'BOARD_BAN_PERM'		=> 'Teidät on asetettu <strong>pysyvästi</strong> porttikieltoon.<br /><br />Ota yhteyttä %2$sKeskustelufoorumin ylläpitäjään%3$s saadaksesi lisää tietoa.',
	'BOARD_BAN_REASON'		=> 'Porttikiellon syy: <strong>%s</strong>',
	'BOARD_BAN_TIME'		=> 'Teille on annettu tilapäinen porttikielto tälle keskustelufoorumille <strong>%1$s</strong> asti.<br /><br />Ota yhteyttä %2$sKeskustelufoorumin ylläpitäjään%3$s saadaksesi lisää tietoa.',
	'BOARD_DISABLE'			=> 'Pahoittelut, mutta tämä keskustelufoorumi on suljettu.',
	'BOARD_DISABLED'		=> 'Tämä keskustelufoorumi on suljettu',
	'BOARD_UNAVAILABLE'		=> 'Pahoittelut, mutta palvelu on tilapäisesti poissa käytöstä. Yritä uudelleen muutaman minuutin kuluttua',
	'BROWSING_FORUM'		=> 'Käyttäjiä lukemassa tätä aluetta: %1$s',
	'BROWSING_FORUM_GUEST'	=> 'Käyttäjiä lukemassa tätä aluetta: %1$s ja %2$d vierailijaa',
	'BROWSING_FORUM_GUESTS'	=> 'Käyttäjiä lukemassa tätä aluetta: %1$s ja %2$d vierailijaa',
	'BYTES'					=> 'Bittiä',

	'CANCEL'				=> 'Peruuta',
	'CHANGE'				=> 'Muuta',
	'CHANGE_FONT_SIZE'		=> 'Muuta fontin kokoa',
	'CHANGING_PREFERENCES'	=> 'Muuttaa omia asetuksia',
	'CHANGING_PROFILE'		=> 'Muuttaa profiilin asetuksia',
	'CLICK_VIEW_PRIVMSG'	=> '%sPalaa saapuneet kansioon%s',
	'COLLAPSE_VIEW'			=> 'Pienennä näkymä',
	'CLOSE_WINDOW'			=> 'Sulje ikkuna',
	'COLOUR_SWATCH'			=> 'Värikartta',
	'COMMA_SEPARATOR'		=> ', ',	// Used in pagination of ACP & prosilver, use localised comma if appropriate, eg: Ideographic or Arabic
	'CONFIRM'				=> 'Hyväksy',
	'CONFIRM_CODE'			=> 'Vahvistuskoodi',
	'CONFIRM_CODE_EXPLAIN'	=> 'Syötä koodi siten kuin se on näkyvillä. Huomioi kirjaisinkoko',
	'CONFIRM_CODE_WRONG'	=> 'Syöttämäsi vahvistuskoodi oli väärin.',
	'CONFIRM_OPERATION'		=> 'Haluatko varmasti suorittaa tämän operaation?',
	'CONGRATULATIONS'		=> 'Onnittelut',
	'CONNECTION_FAILED'		=> 'Yhteysvirhe',
	'CONNECTION_SUCCESS'	=> 'Sain yhteyden',
	'COOKIES_DELETED'		=> 'Kaikki keskustelufoorumin asettamat evästeet on poistettu.',
	'CURRENT_TIME'			=> 'Tänään on %s',

	'DAY'					=> 'Päivä',
	'DAYS'					=> 'Päivää',
	'DELETE'				=> 'Poista',
	'DELETE_ALL'			=> 'Poista kaikki',
	'DELETE_COOKIES'		=> 'Poista evästeet',
	'DELETE_MARKED'			=> 'Poista valitsemasi',
	'DELETE_POST'			=> 'Poista viesti',
	'DELIMITER'				=> 'Erotin',
	'DESCENDING'			=> 'Laskeva',
	'DISABLED'				=> 'Poissa käytöstä',
	'DISPLAY'				=> 'Näytä',
	'DISPLAY_GUESTS'		=> 'Näytä vierailijat',
	'DISPLAY_MESSAGES'		=> 'Näytä viestit ajalta',
	'DISPLAY_POSTS'			=> 'Näytä viestit ajalta',
	'DISPLAY_TOPICS'		=> 'Näytä viestit ajalta',
	'DOWNLOADED'			=> 'Ladattu',
	'DOWNLOADING_FILE'		=> 'Lataa tiedostoa',
	'DOWNLOAD_COUNT'		=> '%d kerran',
	'DOWNLOAD_COUNTS'		=> '%d kertaa',
	'DOWNLOAD_COUNT_NONE'	=> 'Ei ole ladattu kertaakaan',
	'VIEWED_COUNT'			=> 'Katsottu %d kerran',
	'VIEWED_COUNTS'			=> 'Katsottu %d kertaa',
	'VIEWED_COUNT_NONE'		=> 'Ei ole katsottu kertaakaan',

	'EDIT_POST'							=> 'Muokkaa viestiä',
	'EMAIL'								=> 'Sähköposti',
	'EMAIL_ADDRESS'						=> 'Sähköposti',
	'EMAIL_INVALID_EMAIL'				=> 'Antamasi sähköpostiosoite on epäkelpo.',
	'EMAIL_SMTP_ERROR_RESPONSE'			=> 'Sähköpostin lähettämisessä tapahtui virhe <strong>rivillä %1$s</strong>. Vastaus: %2$s',
	'EMPTY_SUBJECT'						=> 'Sinun täytyy antaa otsikko aloittaessasi uutta ketjua.',
	'EMPTY_MESSAGE_SUBJECT'				=> 'Sinun täytyy antaa aihe kirjoittaessasi uutta viestiä.',
	'ENABLED'							=> 'Päällä',
	'ENCLOSURE'							=> 'Liite',
	'ENTER_USERNAME'					=> 'Anna käyttäjätunnus',
	'ERR_CHANGING_DIRECTORY'			=> 'Hakemiston vaihtaminen ei onnistunut',
	'ERR_CONNECTING_SERVER'				=> 'Yhteysvirhe palvelimeen',
	'ERR_JAB_AUTH'						=> 'Jabber-palvelimelle tunnistautuminen epäonnistui.',
	'ERR_JAB_CONNECT'					=> 'Yhteydenotto Jabber-palvelimeen epäonnistui.',
	'ERR_UNABLE_TO_LOGIN'				=> 'Kirjautumisvirhe. Annettu salasana tai käyttäjätunnus ei ole oikein.',
    'ERR_UNWATCHING'       		        => 'Seurannan perumisessa tapahtui virhe.',
    'ERR_WATCHING'              	    => 'Seurannan asetuksessa tapahtui virhe.',
	'ERR_WRONG_PATH_TO_PHPBB'			=> 'Antamasi phpBB:n polku ei ole kelvollinen.',
	'EXPAND_VIEW'						=> 'Laajenna näkymää',
	'EXTENSION'							=> 'Tiedoston tunniste',
	'EXTENSION_DISABLED_AFTER_POSTING'	=> 'Tiedoston tunniste <strong>%s</strong> on poistettu käytöstä, joten tätä liitetiedostoa ei voida näyttää',

	'FAQ'					=> 'UKK',
	'FAQ_EXPLAIN'			=> 'Usein kysyttyä',
	'FILENAME'				=> 'Tiedoston nimi',
	'FILESIZE'				=> 'Tiedoston koko',
	'FILEDATE'				=> 'Tiedoston päivämäärä',
	'FILE_COMMENT'			=> 'Tiedoston kommentti',
	'FILE_NOT_FOUND'		=> 'Pyytämääsi tiedostoa ei löytynyt',
	'FIND_USERNAME'			=> 'Etsi käyttäjä',
	'FOLDER'				=> 'Kansio',
	'FORGOT_PASS'			=> 'Unohdin salasanani',
	'FORM_INVALID'			=> 'Lähetämäsi lomake oli epäkelpo. Yritä lähettää lomake uudelleen.',
	'FORUM'					=> 'Keskustelualue',
	'FORUMS'				=> 'Keskustelualueet',
	'FORUMS_MARKED'			=> 'Alueet ovat merkitty luetuksi',
	'FORUM_CAT'				=> 'Kategoria',
	'FORUM_INDEX'			=> 'Etusivu',
	'FORUM_LINK'			=> 'Linkitetty alue',
	'FORUM_LOCATION'		=> 'Mitä tekemässä?',
	'FORUM_LOCKED'			=> 'Alue on lukittu',
	'FORUM_RULES'			=> 'Alueen säännöt',
	'FORUM_RULES_LINK'		=> 'Paina linkkiä nähdäksesi säännöt',
	'FROM'					=> 'Lähettäjä',
	'FSOCK_DISABLED'		=> 'Operaatiota ei voitu suorittaa loppuun, koska <var>fsockopen</var>-funktio on poissa käytöstä tai pyydettyä palvelinta ei löytynyt.',
	'FSOCK_TIMEOUT'			=> 'Verkossa tapahtui aikakatkaisu luettaessa.',

	'FTP_FSOCK_HOST'				=> 'FTP-palvelin',
	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP-palvelin, jossa saa yhteyden sivustoosi',
	'FTP_FSOCK_PASSWORD'			=> 'FTP:n salasana',
	'FTP_FSOCK_PASSWORD_EXPLAIN'	=> 'Salasana FTP-käyttäjätunnuksellesi',
	'FTP_FSOCK_PORT'				=> 'FTP:n portti',
	'FTP_FSOCK_PORT_EXPLAIN'		=> 'Palvelimen yhteysportti',
	'FTP_FSOCK_ROOT_PATH'			=> 'phpBB:n polku',
	'FTP_FSOCK_ROOT_PATH_EXPLAIN'	=> 'Polku pääjuuresta phpBB-foorumiin',
	'FTP_FSOCK_TIMEOUT'				=> 'FTP:n aikakatkaisu',
	'FTP_FSOCK_TIMEOUT_EXPLAIN'		=> 'Kuinka monta sekuntia järjestelmä odottaa vastausta palvelimelta',
	'FTP_FSOCK_USERNAME'			=> 'FTP:n käyttäjätunnus',
	'FTP_FSOCK_USERNAME_EXPLAIN'	=> 'Käyttäjätunnus, jolla saa yhteyden palvelimeen',

	'FTP_HOST'					=> 'FTP-palvelin',
	'FTP_HOST_EXPLAIN'			=> 'FTP-palvelin, jolla saa yhteyden sivustoosi',
	'FTP_PASSWORD'				=> 'FTP:n salasana',
	'FTP_PASSWORD_EXPLAIN'		=> 'Salasana FTP: käyttäjätunnusta varten',
	'FTP_PORT'					=> 'FTP:n portti',
	'FTP_PORT_EXPLAIN'			=> 'Palvelimesi käyttämä portti',
	'FTP_ROOT_PATH'				=> 'phpBB:n polku',
	'FTP_ROOT_PATH_EXPLAIN'		=> 'Polku pääjuuresta phpBB-foorumiin',
	'FTP_TIMEOUT'				=> 'FTP:n aikakatkaisu',
	'FTP_TIMEOUT_EXPLAIN'		=> 'Kuinka monta sekuntia järjestelmä odottaa vastausta palvelimelta',
	'FTP_USERNAME'				=> 'FTP:n käyttäjätunnus',
	'FTP_USERNAME_EXPLAIN'		=> 'Käyttäjätunnus, jolla saa yhteyden palvelimeen',

	'GENERAL_ERROR'				=> 'Yleinen virhe',
    'GB'						=> 'GB',
    'GIB'						=> 'GiB',
	'GO'						=> 'Suorita',
	'GOTO_PAGE'					=> 'Mene sivulle',
	'GROUP'						=> 'Ryhmä',
	'GROUPS'					=> 'Ryhmiä',
	'GROUP_ERR_TYPE'			=> 'Epäsopiva ryhmän tyyppi valittu.',
	'GROUP_ERR_USERNAME'		=> 'Ryhmän nimeä ei ole määritelty.',
	'GROUP_ERR_USER_LONG'		=> 'Ryhmän nimi on liian pitkä.',
	'GUEST'						=> 'Vieras',
	'GUEST_USERS_ONLINE'		=> '%d vierailijaa paikalla',
	'GUEST_USERS_TOTAL'			=> '%d vierailijaa',
	'GUEST_USERS_ZERO_ONLINE'	=> 'Vierailijoita ei ole',
	'GUEST_USERS_ZERO_TOTAL'	=> 'ei yhtään vierasta',
	'GUEST_USER_ONLINE'			=> '%d vierailijaa paikalla',
	'GUEST_USER_TOTAL'			=> '%d vierailija',
	'G_ADMINISTRATORS'			=> 'Ylläpitäjät',
	'G_BOTS'					=> 'Botit',
	'G_GUESTS'					=> 'Vierailijat',
	'G_REGISTERED'				=> 'Rekisteröityneet käyttäjät',
	'G_REGISTERED_COPPA'		=> 'Rekisteröidyt COPPA-käyttäjät',
	'G_GLOBAL_MODERATORS'		=> 'Valvojat',
	'G_NEWLY_REGISTERED'		=> 'Uudet käyttäjät',

	'HIDDEN_USERS_ONLINE'			=> '%d piilotettua käyttäjää paikalla',
	'HIDDEN_USERS_TOTAL'			=> '%d piilotettua ja ',
	'HIDDEN_USERS_TOTAL_AND'		=> '%d piilotettua ja ',
	'HIDDEN_USERS_ZERO_ONLINE'		=> 'piilotettuja käyttäjiä ei ole paikalla.',
	'HIDDEN_USERS_ZERO_TOTAL'		=> 'ei yhtään piilotettua ja ',
	'HIDDEN_USERS_ZERO_TOTAL_AND'	=> 'ei yhtään piilotettua ja ',
	'HIDDEN_USER_ONLINE'			=> '%d piilotettua käyttäjää paikalla',
	'HIDDEN_USER_TOTAL'				=> '%d piilotettua ja ',
	'HIDDEN_USER_TOTAL_AND'			=> '%d piilotettua ja ',
	'HIDE_GUESTS'					=> 'Piilota vierailijat',
	'HIDE_ME'						=> 'Piilota paikalla olemiseni tällä kertaa',
	'HOURS'							=> 'Tuntia',
	'HOME'							=> 'Koti',

	'ICQ'						=> 'ICQ',
	'ICQ_STATUS'				=> 'ICQ-tilanne',
	'IF'						=> 'jos',
	'IMAGE'						=> 'Kuva',
	'IMAGE_FILETYPE_INVALID'	=> 'Tätä kuvan tyyppiä %d mimetyypille %s ei ole tuettu.',
	'IMAGE_FILETYPE_MISMATCH'	=> 'Kuvatyyppi ei täsmää: odotettiin tunnistetta %1$s, mutta annettiin %2$s.',
	'IN'						=> 'Sijainti:',
	'INDEX'						=> 'Etusivu',
	'INFORMATION'				=> 'Informaatio',
	'INTERESTS'					=> 'Minua kiinnostaa',
	'INVALID_DIGEST_CHALLENGE'	=> 'Epäkelpo tiivistelmä',
	'INVALID_EMAIL_LOG'			=> '<strong>%s</strong> on manhdolisesti epäkelpo sähköpostiosoite',
	'IP'						=> 'IP',
	'IP_BLACKLISTED'			=> 'IP-osoitteesi %1$s on estetty, koska se on lisätty mustalle listalle. Lue linkistä lisätietoja <a href="%2$s">%2$s</a>.',

	'JABBER'				=> 'Jabber',	
	'JOINED'				=> 'Liittynyt',
	'JUMP_PAGE'				=> 'Laita haluamasi sivun numero',
	'JUMP_TO'				=> 'Hyppää',
	'JUMP_TO_PAGE'			=> 'Paina hypätäksesi sivulle...',

	'KB'					=> 'KB',
	'KIB'					=> 'KiB',

	'LAST_POST'							=> 'Uusin viesti',
	'LAST_UPDATED'						=> 'Viimeksi päivitetty',
	'LAST_VISIT'						=> 'Viimeksi vieraillut',
	'LDAP_NO_LDAP_EXTENSION'			=> 'LDAP ei ole saatavilla',
	'LDAP_NO_SERVER_CONNECTION'			=> 'En saanut yhteyttä LDAP-palvelimeen',
    'LDAP_SEARCH_FAILED'                => 'LDAP-hakemiston etsinnässä tapahtui virhe.',
	'LEGEND'							=> 'Selite',
	'LOCATION'							=> 'Paikkakunta',
	'LOCK_POST'							=> 'Lukitse viesti',
	'LOCK_POST_EXPLAIN'					=> 'Estä muokkaus',
	'LOCK_TOPIC'						=> 'Lukitse viestiketju',
	'LOGIN'								=> 'Kirjaudu sisään',
	'LOGIN_CHECK_PM'					=> 'Kirjaudu sisään tarkistaaksesi yksityisviestit',
	'LOGIN_CONFIRMATION'				=> 'kirjautumisen vahvistus',
	'LOGIN_CONFIRM_EXPLAIN'				=> 'Estääkseen käyttäjätunnusten murtamista sivuston ylläpitäjät pyytävät sinua täyttämään varmistuskoodin käytettyäsi maksimimäärän kirjautumisyrityksiä. Koodi näkyy kuvassa, jonka pitäisi näkyä alapuolella. Mikäli olet heikkonäköinen tai et muuten saa koodista selvää, ota yhteyttä keskustelufoorumin %sylläpitäjiin%s.', // Ei käytössä
    'LOGIN_ERROR_ATTEMPTS'              => 'Olet yrittänyt kirjautua sisään liian monta kertaa. Ole hyvä ja syötä myös varmistuskoodi.',
	'LOGIN_ERROR_EXTERNAL_AUTH_APACHE'	=> 'Apache ei ole tunnistanut sinua.',
	'LOGIN_ERROR_PASSWORD'				=> 'Olet antanut väärän salasanan. Ole hyvä ja tarkista salasanasi. Yritä sen jälkeen uudestaan. Mikäli ongelmat jatkuvat, ota yhteyttä sivuston %sylläpitäjiin%s.',
	'LOGIN_ERROR_PASSWORD_CONVERT'		=> 'Salasanasi muuntaminen epäonnistui tätä keskustelufoorumia päivitettäessä. Ole hyvä %sja pyydä uutta salasanaa%s. Mikäli ongelmat jatkuvat, ota yhteyttä %sylläpitäjiin%s.',
	'LOGIN_ERROR_USERNAME'				=> 'Olet antanut väärän käyttäjätunnuksen. Ole hyvä ja tarkista tunnuksesi. Yritä sen jälkeen uudestaan. Mikäli ongelmat jatkuvat, ota yhteyttä sivuston %sylläpitäjiin%s.',
	'LOGIN_FORUM'						=> 'Anna salasana katsoaksesi tai lähettääksesi viestejä tällä alueella.',
	'LOGIN_INFO'						=> 'Sinun tulee olla rekisteröitynyt voidaksesi kirjautua sisään. Rekisteröityminen vie vain hetken, mutta antaa sinulle lisää mahdollisuuksia. Sivuston ylläpitäjä voi myös antaa erityisoikeuksia rekisteröityneille käyttäjille. Muista lukea käyttöehtomme ja siihen liittyvät käytännöt ennen kirjautumista. Muista myös lukea keskustelufoorumin säännöt.',
	'LOGIN_VIEWFORUM'					=> 'Sinun tulee olla rekisteröitynyt käyttäjä ja kirjautunut sisään nähdäksesi tämän alueen.',
	'LOGIN_EXPLAIN_EDIT'				=> 'Sinun tulee olla rekisteröitynyt käyttäjä ja kirjautunut sisään muokataksesi viestejä tällä alueella.',
	'LOGIN_EXPLAIN_VIEWONLINE'			=> 'Kirjaudu sisään katsoaksesi paikallaolijoiden listaa',
	'LOGOUT'							=> 'Kirjaudu ulos',
	'LOGOUT_USER'						=> 'Kirjaudu ulos [ %s ]',
	'LOG_ME_IN'							=> 'Kirjaudu automaattisesti sisään.',

	'MARK'					=> 'Valitse',
	'MARK_ALL'				=> 'Valitse kaikki',
	'MARK_FORUMS_READ'		=> 'Merkitse kaikki alueet luetuiksi',
    'MARK_SUBFORUMS_READ'   => 'Merkitse sisäalueet luetuksi',
	'MB'					=> 'MB',
	'MIB'					=> 'MiB',
	'MCP'					=> 'Valvojien hallintapaneeli',
	'MEMBERLIST'			=> 'Käyttäjät',
	'MEMBERLIST_EXPLAIN'	=> 'Näytä täydellinen jäsenlista',
	'MERGE'					=> 'Yhdistä',
	'MERGE_POSTS'			=> 'Siirrä viestit',
	'MERGE_TOPIC'			=> 'Yhdistä viestiketjut',
	'MESSAGE'				=> 'Viesti',
	'MESSAGES'				=> 'Viestejä',
	'MESSAGE_BODY'			=> 'Viestin sisältö',
	'MINUTES'				=> 'Minuuttia',
	'MODERATE'				=> 'Hallinnoi',
	'MODERATOR'				=> 'Valvoja',
	'MODERATORS'			=> 'Valvojat',
	'MONTH'					=> 'Kuukausi',
	'MOVE'					=> 'Siirrä',
	'MSNM'					=> 'MSNM/WLM',	

	'NA'						=> 'N/A',
	'NEWEST_USER'				=> 'Uusin käyttäjä <strong>%s</strong>',
	'NEW_MESSAGE'				=> 'uusi viesti',
	'NEW_MESSAGES'				=> 'uusia viestejä',
	'NEW_PM'					=> '<strong>%d</strong> uusi viesti',
	'NEW_PMS'					=> '<strong>%d</strong> uusia viestejä',
	'NEW_POST'					=> 'Uusi viesti', // ei käytössä
	'NEW_POSTS'					=> 'Uusia viestejä', // ei käytössä
	'NEXT'						=> 'Seuraava',
	'NEXT_STEP'					=> 'Seuraava',
	'NEVER'						=> 'Ei koskaan',
	'NO'						=> 'Ei',
	'NOT_ALLOWED_MANAGE_GROUP'	=> 'Et voi muokata tätä ryhmää ylläpidon hallintapaneelista.',
	'NOT_AUTHORISED'			=> 'Sinulla ei ole pääsyä tälle alueelle.',
	'NOT_WATCHING_FORUM'		=> 'Tämän keskustelualueen seuraaminen on lopetettu.',
	'NOT_WATCHING_TOPIC'		=> 'Tämän viestiketjun seuraaminen on lopetettu.',
	'NOTIFY_ADMIN'				=> 'Ole hyvä ja ilmoita tästä keskustelufoorumin ylläpitäjälle, tai webmasterille.',
	'NOTIFY_ADMIN_EMAIL'		=> 'Ole hyvä ja ilmoita tästä keskustelufoorumin ylläpitäjälle, tai webmasterille: <a href="mailto:%1$s">%1$s</a>',
	'NO_ACCESS_ATTACHMENT'		=> 'Tämän tiedoston käyttö on estetty.',
	'NO_ACTION'					=> 'Toimintoa ei ole määritetty.',
	'NO_ADMINISTRATORS'			=> 'Ei ylläpitäjiä.',
	'NO_AUTH_ADMIN'				=> 'Sinulla ei ole ylläpitäjän oikeuksia, joten et voi muokata ylläpidon asetuksia.',
	'NO_AUTH_ADMIN_USER_DIFFER'	=> 'Et voi tunnistautua toisena käyttäjänä.',
	'NO_AUTH_OPERATION'			=> 'Käyttö-oikeutesi eivät riitä tämän toiminnon suorittamiseen.',
	'NO_CONNECT_TO_SMTP_HOST'	=> 'En saanut yhteyttä SMTP-palvelimeen : %s : %s',
	'NO_BIRTHDAYS'				=> 'Ei syntymäpäiviä tänään',
	'NO_EMAIL_MESSAGE'			=> 'Sähköpostin viesti oli tyhjä',
	'NO_EMAIL_RESPONSE_CODE'	=> 'En saanut sähköpostipalvelimen vastauskoodeja',
	'NO_EMAIL_SUBJECT'			=> 'Sähköpostin otsikkoa ei ole määritetty',
	'NO_FORUM'					=> 'Valitsemaasi aluetta ei ole olemassa',
	'NO_FORUMS'					=> 'Tällä keskustelufoorumilla ei ole yhtään aluetta',
	'NO_GROUP'					=> 'Hakemaasi käyttäjäryhmää ei ole olemassa.',
	'NO_GROUP_MEMBERS'			=> 'Tähän ryhmään ei oteta uusia käyttäjiä tällä hetkellä',
	'NO_IPS_DEFINED'			=> 'Ei IP-osoitteita tai palvelimia määriteltynä',
	'NO_MEMBERS'				=> 'Hakukriteereillä ei löytynyt yhtään käyttäjää',
	'NO_MESSAGES'				=> 'Ei viestejä',
	'NO_MODE'					=> 'Moodia ei ole määritelty.',
	'NO_MODERATORS'				=> 'Ei valvojia.',
	'NO_NEW_MESSAGES'			=> 'Ei uusia viestejä',
	'NO_NEW_PM'					=> '<strong>0</strong> uutta viestiä',
	'NO_NEW_POSTS'				=> 'Ei uusia viestejä', // ei käytössä
	'NO_ONLINE_USERS'			=> 'Ei rekisteröityneitä käyttäjiä',
	'NO_POSTS'					=> 'Ei viestejä',
	'NO_POSTS_TIME_FRAME'		=> 'Tässä viestiketjussa ei ole uusia viestejä valitsemaltasi aikaväliltä.',
	'NO_FEED_ENABLED'			=> 'Syötteet eivät ole käytössä tällä keskustelufoorumilla.',
	'NO_FEED'					=> 'Pyytämäsi syöte ei ole saatavilla.',
	'NO_STYLE_DATA'				=> 'Tyylin tietoja ei saatu',
	'NO_SUBJECT'				=> 'Otsikkoa ei ole määritelty',
	'NO_SUCH_SEARCH_MODULE'		=> 'Antamaasi hakumoottoria ei ole olemassa',
	'NO_SUPPORTED_AUTH_METHODS'	=> 'Ei tuettuja tunnistautumismenetelmiä',
	'NO_TOPIC'					=> 'Hakemaasi viestiketjua ei löytynyt.',
	'NO_TOPIC_FORUM'			=> 'Viestiketjua tai aluetta ei ole enää olemassa.',
	'NO_TOPICS'					=> 'Tällä alueella ei ole viestejä.',
	'NO_TOPICS_TIME_FRAME'		=> 'Tällä alueella ei ole uusia viestejä valitsemaltasi aikaväliltä.',
	'NO_UNREAD_PM'				=> '<strong>0</strong> lukematonta viestiä',
    'NO_UNREAD_POSTS'           => 'Ei lukemattomia viestejä',
	'NO_UPLOAD_FORM_FOUND'		=> 'Tiedoston siirto aloitettiin, mutta sopivaa muotoa tiedoston siirtoon ei löytynyt.',
	'NO_USER'					=> 'Valitsemaasi käyttäjää ei ole olemassa.',
	'NO_USERS'					=> 'valitsemiasi käyttäjiä ei ole olemassa',
	'NO_USER_SPECIFIED'			=> 'Käyttäjätunnusta ei ole määritelty',

       // Nullar/Singular/Plural language entry. The key numbers define the number range in which a certain grammatical expression is valid.
       'NUM_POSTS_IN_QUEUE'      => array(
          0         => 'Ei viestejä jonossa',      // 0
          1         => 'Yksi viesti jonossa',      // 1
          2         => '%d viestiä jonossa',      // 2+
       ),


	'OCCUPATION'				=> 'Ammatti',
	'OFFLINE'					=> 'Poissa',
	'ONLINE'					=> 'Paikalla',
	'ONLINE_BUDDIES'			=> 'Paikalla olevat kaverit',
	'ONLINE_USERS_TOTAL'		=> 'Yhteensä <strong>%d</strong> käyttäjää paikalla :: ',
	'ONLINE_USERS_ZERO_TOTAL'	=> 'Ei käyttäjiä paikalla :: ',
	'ONLINE_USER_TOTAL'			=> 'Yhteensä <strong>%d</strong> käyttäjää paikalla :: ',
	'OPTIONS'					=> 'Vaihtoehdot',

	'PAGE_OF'				=> 'Sivu <strong>%1$d</strong>/<strong>%2$d</strong>',
	'PASSWORD'				=> 'Salasana',
	'PIXEL'					=> 'px',
	'PLAY_QUICKTIME_FILE'	=> 'Toista Quicktime-tiedosto',
	'PM'					=> 'Yksityisviesti',
    'PM_REPORTED'           => 'Napsauta nähdäksesi ilmoituksen',
	'POSTING_MESSAGE'		=> 'Kirjoittaa viestiä alueella %s',
	'POSTING_PRIVATE_MESSAGE'	=> 'Kirjoittaa yksityisviestiä',
	'POST'					=> 'Viesti',
	'POST_ANNOUNCEMENT'		=> 'Pysyvä tiedote',
	'POST_STICKY'			=> 'Tiedote',
	'POSTED'				=> 'Lähetetty',
	'POSTED_IN_FORUM'		=> 'alueella',
	'POSTED_ON_DATE'		=> '»',
	'POSTS'					=> 'Viestit',
	'POSTS_UNAPPROVED'		=> 'Ainakin yhtä tässä ketjussa olevaa viestiä ei ole hyväksytty',
	'POST_BY_AUTHOR'		=> 'Kirjoittaja',
    'POST_BY_FOE'           => 'Tämän viestin lähetti <strong>%1$s</strong>, joka on hylkäyslistallasi. Paina %2$sTÄSTÄ%3$s nähdäksesi kyseisen viestin.',
    'POST_DAY'				=> '%.2f viestiä päivässä',
	'POST_DETAILS'			=> 'Viestin yksityiskohdat',
	'POST_NEW_TOPIC'		=> 'Aloita uusi ketju',
	'POST_PCT'				=> '%.2f%% kaikista viesteistä',
	'POST_PCT_ACTIVE'		=> '%.2f%% viesteistä',
	'POST_PCT_ACTIVE_OWN'	=> '%.2f%% viesteistäsi',
	'POST_REPLY'			=> 'Lähetä vastaus',
	'POST_REPORTED'			=> 'Paina nähdäksesi raportin',
	'POST_SUBJECT'			=> 'Viestin otsikko',
	'POST_TIME'				=> 'Päiväys',
	'POST_TOPIC'			=> 'Lähetä uusi viesti',
	'POST_UNAPPROVED'		=> 'Tämä viesti odottaa hyväksyntää',
	'POWERED_BY'			=> 'Keskustelufoorumin moottorina toimii %s',
	'PREVIEW'				=> 'Esikatselu',
	'PREVIOUS'				=> 'Edellinen',
	'PREVIOUS_STEP'			=> 'Edellinen',
	'PRIVACY'				=> 'Yksityisyyden suoja',
	'PRIVATE_MESSAGE'		=> 'Yksityisviesti',
	'PRIVATE_MESSAGES'		=> 'Yksityisviestejä',
	'PRIVATE_MESSAGING'		=> 'Yksityisviestin lähetys',
	'PROFILE'				=> 'Omat asetukset',
	'RANK'					=> 'Arvonimi',

	'READING_FORUM'				=> 'Lukee keskustelualuetta %s',
	'READING_GLOBAL_ANNOUNCE'	=> 'Lukee yleistiedotetta',
	'READING_LINK'				=> 'Seuraa linkkiä %s',
	'READING_TOPIC'				=> 'Lukee viestiä %s -alueella',
	'READ_PROFILE'				=> 'Profiili',
	'REASON'					=> 'Syy',
	'RECORD_ONLINE_USERS'		=> 'Eniten yhtaikaisia käyttäjiä on ollut <strong>%1$s</strong> kpl, %2$s',
	'REDIRECT'					=> 'Uudelleenohjaus',
	'REDIRECTS'					=> 'Ohjauksia yhteensä',
	'REGISTER'					=> 'Rekisteröidy',
	'REGISTERED_USERS'			=> 'Rekisteröityneet käyttäjät:<br />',
	'REG_USERS_ONLINE'			=> '%d rekisteröitynyttä käyttäjää ja ',
	'REG_USERS_TOTAL'			=> '%d rekisteröitynyttä, ',
	'REG_USERS_TOTAL_AND'		=> '%d rekisteröitynyttä ja ',
	'REG_USERS_ZERO_ONLINE'		=> 'Ei rekisteröityneitä ja ',
	'REG_USERS_ZERO_TOTAL'		=> 'Ei rekisteröityneitä, ',
	'REG_USERS_ZERO_TOTAL_AND'	=> 'Ei rekisteröityneitä ja ',
	'REG_USER_ONLINE'			=> 'Paikalla on %d rekisteröitynyttä. ',
	'REG_USER_TOTAL'			=> '%d rekisteröitynyttä, ',
	'REG_USER_TOTAL_AND'		=> '%d rekisteröitynyttä ja ',
	'REMOVE'					=> 'Poista',
	'REMOVE_INSTALL'			=> 'Ole hyvä ja poista, siirrä tai muuta install-hakemiston nimeä. Mikäli tämä hakemisto on palvelimella, vain ylläpidon asetukset ovat käytettävissä.',
	'REPLIES'					=> 'Vastaukset',
	'REPLY_WITH_QUOTE'			=> 'Vastaa lainaamalla',
	'REPLYING_GLOBAL_ANNOUNCE'	=> 'Vastaa yleistiedotteeseen',
	'REPLYING_MESSAGE'			=> 'Vastaa viestiin %s -alueella',
	'REPORT_BY'					=> 'Ilmoittanut',
	'REPORT_POST'				=> 'Ilmoita tämä viesti',
	'REPORTING_POST'			=> 'Ilmoittaa viestiä',
	'RESEND_ACTIVATION'			=> 'Lähetä tunnusten aktivointiviesti uudelleen',
	'RESET'						=> 'Tyhjennä',
	'RESTORE_PERMISSIONS'		=> 'Palauta oikeudet',
	'RETURN_INDEX'				=> '%sPalaa etusivulle%s',
	'RETURN_FORUM'				=> '%sPalaa alueelle, jossa olit viimeksi%s',
	'RETURN_PAGE'				=> '%sPalaa edelliselle sivulle%s',
	'RETURN_TOPIC'				=> '%sPalaa viestiin, jota luit viimeksi%s',
	'RETURN_TO'					=> 'Paluu',
	'FEED'						=> 'Syöte',
	'FEED_NEWS'					=> 'Uutiset',
	'FEED_TOPICS_ACTIVE'		=> 'Aktiiviset viestiketjut',
	'FEED_TOPICS_NEW'			=> 'Uudet viestiketjut',
	'RULES_ATTACH_CAN'			=> '<strong>Voit</strong> lähettää liitetiedostoja',
	'RULES_ATTACH_CANNOT'		=> '<strong>Et voi</strong> lähettää liitetiedostoja',
	'RULES_DELETE_CAN'			=> '<strong>Voit</strong> poistaa omat viestisi',
	'RULES_DELETE_CANNOT'		=> '<strong>Et voi</strong> poistaa omia viestejäsi',
	'RULES_DOWNLOAD_CAN'		=> '<strong>Voit</strong> ladata liitetiedostoja',
	'RULES_DOWNLOAD_CANNOT'		=> '<strong>Et voi</strong> ladata liitetiedostoja',
	'RULES_EDIT_CAN'			=> '<strong>Voit</strong> muokata omia viestejäsi',
	'RULES_EDIT_CANNOT'			=> '<strong>Et voi</strong> muokata omia viestejäsi',
	'RULES_LOCK_CAN'			=> '<strong>Voit</strong> lukita omat viestisi',
	'RULES_LOCK_CANNOT'			=> '<strong>Et voi</strong> lukita omia viestejäsi',
	'RULES_POST_CAN'			=> '<strong>Voit</strong> kirjoittaa uusia viestejä',
	'RULES_POST_CANNOT'			=> '<strong>Et voi</strong> kirjoittaa uusia viestejä',
	'RULES_REPLY_CAN'			=> '<strong>Voit</strong> vastata viestiketjuihin',
	'RULES_REPLY_CANNOT'		=> '<strong>Et voi</strong> vastata viestiketjuihin',
	'RULES_VOTE_CAN'			=> '<strong>Voit</strong> äänestää',
	'RULES_VOTE_CANNOT'			=> '<strong>Et voi</strong> äänestää',

	'SEARCH'					=> 'Etsi',
	'SEARCH_MINI'				=> 'Etsi…',
	'SEARCH_ADV'				=> 'Tarkennettu haku',
	'SEARCH_ADV_EXPLAIN'		=> 'Näytä tarkan haun vaihtoehdot',
	'SEARCH_KEYWORDS'			=> 'Etsi avainsanoja',
	'SEARCHING_FORUMS'			=> 'Etsimässä',
	'SEARCH_ACTIVE_TOPICS'		=> 'Näytä aktiiviset viestiketjut',
	'SEARCH_FOR'				=> 'Etsi tätä',
	'SEARCH_FORUM'				=> 'Etsi tältä alueelta',	
	'SEARCH_NEW'				=> 'Näytä uudet viestit',
	'SEARCH_POSTS_BY'			=> 'Etsi viestejä käyttäjältä',
	'SEARCH_SELF'				=> 'Näytä omat viestit',
	'SEARCH_TOPIC'				=> 'Etsi viestiketjusta',
	'SEARCH_UNANSWERED'			=> 'Näytä vastaamattomat viestit',
	'SEARCH_UNREAD'				=> 'Näytä lukemattomat viestit',
    'SEARCH_USER_POSTS'         => 'Etsi käyttäjän viesteistä',
	'SECONDS'					=> 'Sekuntia',
	'SELECT'					=> 'Valitse',
	'SELECT_ALL_CODE'			=> 'Valitse kaikki',
	'SELECT_DESTINATION_FORUM'	=> 'Valitse kohdealue',
	'SELECT_FORUM'				=> 'Valitse alue',
	'SEND_EMAIL'				=> 'Lähetä sähköpostia',
	'SEND_EMAIL_USER'			=> 'Lähetä sähköpostia käyttäjälle',				// Used as: {L_SEND_EMAIL_USER} {USERNAME} -> E-mail UserX
	'SEND_PRIVATE_MESSAGE'		=> 'Lähetä yksityisviesti',
	'SETTINGS'					=> 'Asetukset',
	'SIGNATURE'					=> 'Allekirjoitus',
	'SKIP'						=> 'Hyppää sisältöön',
	'SMTP_NO_AUTH_SUPPORT'		=> 'SMTP-palvelin ei tue tunnistautumista',
	'SORRY_AUTH_READ'			=> 'Sinulla ei ole tarvittavia oikeuksia tämän alueen lukemiseen',
	'SORRY_AUTH_VIEW_ATTACH'	=> 'Sinulla ei ole tarvittavia oikeuksia liitetiedoston lataamiseen',
	'SORT_BY'					=> 'Järjestä',
	'SORT_JOINED'				=> 'Liittynyt',
	'SORT_LOCATION'				=> 'paikka',
	'SORT_RANK'					=> 'Arvonimi',
	'SORT_POSTS'				=> 'Viestit',
	'SORT_TOPIC_TITLE'			=> 'Viestin otsikko',
	'SORT_USERNAME'				=> 'käyttäjätunnus',
	'SPLIT_TOPIC'				=> 'Jaa viestiketju',
	'SQL_ERROR_OCCURRED'		=> 'Tapahtui SQL-virhe tätä sivua noudettaessa. Ole hyvä ja ota yhteyttä %skeskustelufoorumin ylläpitäjiin%s mikäli tämä ongelma jatkuu.',
	'STATISTICS'				=> 'Tilastot',
	'START_WATCHING_FORUM'		=> 'Seuraa aluetta',
	'START_WATCHING_TOPIC'		=> 'Seuraa vastauksia',
	'STOP_WATCHING_FORUM'		=> 'Lopeta seuranta',
	'STOP_WATCHING_TOPIC'		=> 'Lopeta seuranta',
	'SUBFORUM'					=> 'Sisäalue',
	'SUBFORUMS'					=> 'Sisäalueet',
	'SUBJECT'					=> 'Otsikko',
	'SUBMIT'					=> 'Lähetä',
	'TB'				=> 'TB',

	'TERMS_USE'			=> 'Käyttöehdot',
	'TEST_CONNECTION'	=> 'Testaa yhteys',
	'THE_TEAM'			=> 'Henkilökunta',
	'TIB'				=> 'TiB',
	'TIME'				=> 'Aika',
    'TOO_LARGE'                     => 'Antamasi arvo on liian suuri.',
    'TOO_LARGE_MAX_RECIPIENTS'      => 'Maksimi arvo <strong>yksityisviestien vastaanottajamäärälle</strong> on liian suuri.',
    'TOO_LONG'                      => 'Antamasi arvo on liian pitkä.',

	'TOO_LONG_AIM'					=> 'Antamasi näyttönimi on liian pitkä.',
	'TOO_LONG_CONFIRM_CODE'			=> 'Antamasi varmistuskoodi on liian pitkä.',
	'TOO_LONG_DATEFORMAT'			=> 'Antamasi päiväyksen muoto on liian pitkä.',
	'TOO_LONG_ICQ'					=> 'Antamasi ICQ-numero on liian pitkä.',
	'TOO_LONG_INTERESTS'			=> 'Antamasi mielenkiinnon kohde on liian pitkä.',
	'TOO_LONG_JABBER'				=> 'Antamasi Jabber-tilin nimi on liian pitkä.',
	'TOO_LONG_LOCATION'				=> 'Antamasi paikannimi on liian pitkä.',
	'TOO_LONG_MSN'					=> 'Antamasi MSN-nimi on liian pitkä.',
	'TOO_LONG_NEW_PASSWORD'			=> 'Antamasi salasana on liian pitkä.',
	'TOO_LONG_OCCUPATION'			=> 'Antamasi ammatti on liian pitkä.',
	'TOO_LONG_PASSWORD_CONFIRM'		=> 'Antamasi salasanan vahvistus on liian pitkä.',
	'TOO_LONG_USER_PASSWORD'		=> 'Antamasi salasana on liian pitkä.',
	'TOO_LONG_USERNAME'				=> 'Antamasi käyttäjätunnus on liian pitkä.',
	'TOO_LONG_EMAIL'				=> 'Antamasi sähköpostiosoite on liian pitkä.',
	'TOO_LONG_EMAIL_CONFIRM'		=> 'Antamasi sähköpostin varmistus on liian pitkä.',
	'TOO_LONG_WEBSITE'				=> 'Antamasi nettisivun osoite on liian pitkä.',
	'TOO_LONG_YIM'					=> 'Antamasi Yahoo! Messenger -nimi on liian pitkä.',

	'TOO_MANY_VOTE_OPTIONS'			=> 'Olet yrittänyt äänestää liian montaa vaihtoehtoa.',
    'TOO_SHORT'                  	=> 'Antamasi arvo on liian lyhyt.',

	'TOO_SHORT_AIM'					=> 'Antamasi näyttönimi on liian lyhyt.',
	'TOO_SHORT_CONFIRM_CODE'		=> 'Antamasi varmistuskoodi on liian lyhyt.',
	'TOO_SHORT_DATEFORMAT'			=> 'Antamasi päiväyksen muoto on liian lyhyt.',
	'TOO_SHORT_ICQ'					=> 'Antamasi ICQ-numero on liian lyhyt.',
	'TOO_SHORT_INTERESTS'			=> 'Antamasi mielenkiinnon kohde on liian lyhyt.',
	'TOO_SHORT_JABBER'				=> 'Antamasi Jabber-tilin nimi on liian lyhyt.',
	'TOO_SHORT_LOCATION'			=> 'Antamasi sijainti on liian lyhyt.',
	'TOO_SHORT_MSN'					=> 'Antamasi MSN-nimi on liian lyhyt.',
	'TOO_SHORT_NEW_PASSWORD'		=> 'Antamasi salasana on liian lyhyt.',
	'TOO_SHORT_OCCUPATION'			=> 'Antamasi ammatti on liian lyhyt.',
	'TOO_SHORT_PASSWORD_CONFIRM'	=> 'Antamasi salasanan vahvistus on liian lyhyt.',
	'TOO_SHORT_USER_PASSWORD'		=> 'Antamasi salasana on liian lyhyt.',
	'TOO_SHORT_USERNAME'			=> 'Antamasi käyttäjätunnus on liian lyhyt.',
	'TOO_SHORT_EMAIL'				=> 'Antamasi sähköpostiosoite on liian lyhyt.',
	'TOO_SHORT_EMAIL_CONFIRM'		=> 'Antamasi sähköpostiosoitteen varmistus on liian lyhyt.',
	'TOO_SHORT_WEBSITE'				=> 'Antamasi nettisivun osoite on liian lyhyt.',
	'TOO_SHORT_YIM'					=> 'Antamasi Yahoo! Messenger -nimi on liian lyhyt.',
    'TOO_SMALL'                     => 'Antamasi arvo on liian pieni.',
	'TOO_SMALL_MAX_RECIPIENTS'      => 'Enimmäisarvo <strong>yksityisviestien vastaanottajamäärälle</strong> on liian pieni.',

	'TOPIC'				=> 'Aihe',
	'TOPICS'			=> 'Aiheet',
	'TOPICS_UNAPPROVED'	=> 'Tällä alueella on ainakin yksi viesti odottamassa hyväksyntää.',
	'TOPIC_ICON'		=> 'Aiheen kuvake',
	'TOPIC_LOCKED'		=> 'Tämä viestiketju on lukittu. Et voi vastata tai muokata viestejäsi',
	'TOPIC_LOCKED_SHORT'=> 'Viestiketju on lukittu',
	'TOPIC_MOVED'		=> 'Siirretty viestiketju',
	'TOPIC_REVIEW'		=> 'Otsikko',
	'TOPIC_TITLE'		=> 'Viestin otsikko',
	'TOPIC_UNAPPROVED'	=> 'Tätä aihetta ei ole hyväksytty',
	'TOTAL_ATTACHMENTS'	=> 'liitteet',
	'TOTAL_LOG'			=> '1 loki',
	'TOTAL_LOGS'		=> '%d kirjattua tapahtumaa',
	'TOTAL_NO_PM'		=> 'Ei uusia viestejä',
	'TOTAL_PM'			=> '1 yksityisviesti',
	'TOTAL_PMS'			=> '%d yksityisviestiä',
	'TOTAL_POSTS'		=> 'Viestejä yhteensä',
	'TOTAL_POSTS_OTHER'	=> 'Viestejä yhteensä <strong>%d</strong>',
	'TOTAL_POSTS_ZERO'	=> 'Viestejä yhteensä <strong>0</strong>',
	'TOPIC_REPORTED'	=> 'Tämä ketju on ilmoitettu',
	'TOTAL_TOPICS_OTHER'=> 'Viestiketjuja on yhteensä <strong>%d</strong> kappaletta',
	'TOTAL_TOPICS_ZERO'	=> 'Viestiketjuja on yhteensä <strong>0</strong> kappaletta',
	'TOTAL_USERS_OTHER'	=> 'Käyttäjiä yhteensä <strong>%d</strong>',
	'TOTAL_USERS_ZERO'	=> 'Käyttäjiä on yhteensä <strong>0</strong> kappaletta',
	'TRACKED_PHP_ERROR'	=> 'Seuratut PHP-virheet: %s',

	'UNABLE_GET_IMAGE_SIZE'	=> 'Kuvan koon määritteleminen ei onnistunut.',
	'UNABLE_TO_DELIVER_FILE'=> 'Tiedoston toimittaminen ei onnistu.',
	'UNKNOWN_BROWSER'		=> 'Tunnistamaton selain',
	'UNMARK_ALL'			=> 'Poista valinnat',
	'UNREAD_MESSAGES'		=> 'Lukemattomat viestit',
	'UNREAD_PM'				=> '<strong>%d</strong> lukematon viesti',
	'UNREAD_PMS'			=> '<strong>%d</strong> lukemattomia viestejä',
    'UNREAD_POST'           => 'Lukematon viesti',
    'UNREAD_POSTS'          => 'Lukemattomat viestit',
	'UNWATCH_FORUM_CONFIRM'		=> 'Haluatko lopettaa tämän alueen seurannan?',
	'UNWATCH_FORUM_DETAILED'	=> 'Haluatko varmasti lopettaa “%s” seurannan?',
	'UNWATCH_TOPIC_CONFIRM'		=> 'Haluatko lopettaa tämän viestiketjun seurannan?',
	'UNWATCH_TOPIC_DETAILED'	=> 'Haluatko varmasti lopettaa “%s” seurannan?',
	'UNWATCHED_FORUMS'		=> 'Et enää seuraa valitsemaasi aluetta.',
	'UNWATCHED_TOPICS'		=> 'Et enää seuraa valitsemaasi viestiketjua.',
	'UNWATCHED_FORUMS_TOPICS'	=> 'Et enää seuraa valitsemiasi merkintöjä.',
	'UPDATE'				=> 'Päivitä',
	'UPLOAD_IN_PROGRESS'	=> 'Siirto käynnissä',
	'URL_REDIRECT'			=> 'Mikäli selaimesi ei tue meta-uudelleenohjausta, napsauta %sTÄSTÄ%s jatkaaksesi eteenpäin.',
	'USERGROUPS'			=> 'Ryhmät',
	'USERNAME'				=> 'Käyttäjätunnus',
	'USERNAMES'				=> 'Käyttäjätunnukset',
	'USER_AVATAR'			=> 'Avatar',
	'USER_CANNOT_READ'		=> 'Et voi lukea viestejä tällä alueella',
	'USER_POST'				=> '%d viesti',
	'USER_POSTS'			=> '%d viestiä',
	'USERS'					=> 'käyttäjiä',
	'USE_PERMISSIONS'		=> 'Testaa oikeudet',
	'USER_NEW_PERMISSION_DISALLOWED'	=> 'Pahoittelemme, mutta tämän toiminnon käyttäminen ei ole juuri nyt sallittua. Jos olet rekisteröitynyt vasta äskettäin, voit joutua osallistumaan keskusteluihin enemmän käyttääksesi tätä toimintoa.',

	'VARIANT_DATE_SEPARATOR'	=> ' / ',	// Used in date format dropdown, eg: "Today, 13:37 / 01 Jan 2007, 13:37" ... to join a relative date with calendar date
	'VIEWED'					=> 'Katselee',
	'VIEWING_FAQ'				=> 'Lukee vastauksia yleisimpiin kysymyksiin',
	'VIEWING_MEMBERS'			=> 'Katselee käyttäjiä',
	'VIEWING_ONLINE'			=> 'Katselee listaa paikallaolijoista',
	'VIEWING_MCP'				=> 'Käyttää valvojien hallintapaneelia',
	'VIEWING_MEMBER_PROFILE'	=> 'Katselee käyttäjän profiilia',
	'VIEWING_PRIVATE_MESSAGES'	=> 'Lukee omia yksityisviestejään',
	'VIEWING_REGISTER'			=> 'Rekisteröi käyttäjätunnusta',
	'VIEWING_UCP'				=> 'Muokkaa omia asetuksia',
	'VIEWS'						=> 'Luettu',
	'VIEW_BOOKMARKS'			=> 'Näytä kirjanmerkit',
	'VIEW_FORUM_LOGS'			=> 'Näytä lokitiedot',
	'VIEW_LATEST_POST'			=> 'Näytä uusin viesti',
	'VIEW_NEWEST_POST'			=> 'Näytä ensimmäinen lukematon viesti',
	'VIEW_NOTES'				=> 'Näytä muistiinpanot',
	'VIEW_ONLINE_TIME'			=> 'Tieto perustuu viimeisen %d minuutin aikana olleisiin aktiivisiin käyttäjiin',
	'VIEW_ONLINE_TIMES'			=> 'Tieto perustuu viimeisen %d minuutin aikana olleisiin aktiivisiin käyttäjiin',
	'VIEW_TOPIC'				=> 'katso viestiketjua',
	'VIEW_TOPIC_ANNOUNCEMENT'	=> 'Tiedote: ',
	'VIEW_TOPIC_GLOBAL'			=> 'Yleistiedote: ',
	'VIEW_TOPIC_LOCKED'			=> 'Lukittu: ',
	'VIEW_TOPIC_LOGS'			=> 'Katso lokitiedot',
	'VIEW_TOPIC_MOVED'			=> 'Siirretty: ',
	'VIEW_TOPIC_POLL'			=> 'Äänestys: ',
	'VIEW_TOPIC_STICKY'			=> 'Pysyvä: ',
	'VISIT_WEBSITE'				=> 'Vieraile sivustolla',

	'WARNINGS'			=> 'Varoitukset',
	'WARN_USER'			=> 'Anna varoitus',
	'WATCH_FORUM_CONFIRM'	=> 'Haluatko varmasti seurata tätä aluetta?',
	'WATCH_FORUM_DETAILED'	=> 'Haluatko varmasti seurata aluetta“%s”?',
	'WATCH_TOPIC_CONFIRM'	=> 'Haluatko varmasti seurata tätä viestiketjua?',
	'WATCH_TOPIC_DETAILED'	=> 'Haluatko varmasti seurata viestiketjua “%s”?',
	'WELCOME_SUBJECT'	=> 'Tervetuloa %s keskustelufoorumille',
	'WEBSITE'			=> 'Kotisivu',
	'WHOIS'				=> 'Whois',
	'WHO_IS_ONLINE'		=> 'Paikallaolijat',
	'WRONG_PASSWORD'	=> 'Annoit väärän salasanan.',
	'WRONG_DATA_COLOUR'			=> 'Antamasi väriarvo ei kelpaa.',

	'WRONG_DATA_ICQ'			=> 'Antamasi numero ei ole kelvollinen ICQ-numero.',
	'WRONG_DATA_JABBER'			=> 'Antamasi nimi ei ole kelvollinen Jabber-tilin nimi.',
	'WRONG_DATA_LANG'			=> 'Antamasi kieli ei ole kelvollinen.',
	'WRONG_DATA_WEBSITE'		=> 'Antamasi sivun osoitteen täytyy olla täydellinen, mukaanluettuna protokolla. Esimerkiksi http://www.esimerkki.com/.',
	'WROTE'						=> 'kirjoitti',

	'YEAR'				=> 'Vuosi',
	'YEAR_MONTH_DAY'	=> '(VVVV-KK-PP)',
	'YES'				=> 'Kyllä',
	'YIM'				=> 'YIM',
	'YOU_LAST_VISIT'	=> 'Viimeisin vierailu: %s',
	'YOU_NEW_PM'		=> 'Saapuneet-kansiossa on yksi uusi yksityisviesti',
	'YOU_NEW_PMS'		=> 'Saapuneet-kansiossa on uusia yksityisviestejä',
	'YOU_NO_NEW_PM'		=> 'Ei uusia yksityisviestejä',

	'datetime'			=> array(
		'TODAY'		=> 'Tänään',
		'TOMORROW'	=> 'Huomenna',
		'YESTERDAY'	=> 'Eilen',
		'AGO'		=> array(
			0		=> 'Alle minuutti sitten',
			1		=> '%d minuutti sitten',
			2		=> '%d minuuttia sitten',
			60		=> 'Tunti sitten',
		),

		'Sunday'	=> 'Sunnuntai',
		'Monday'	=> 'Maanantai',
		'Tuesday'	=> 'Tiistai',
		'Wednesday'	=> 'Keskiviikko',
		'Thursday'	=> 'Torstai',
		'Friday'	=> 'Perjantai',
		'Saturday'	=> 'Lauantai',

		'Sun'		=> 'Su',
		'Mon'		=> 'Ma',
		'Tue'		=> 'Ti',
		'Wed'		=> 'Ke',
		'Thu'		=> 'To',
		'Fri'		=> 'Pe',
		'Sat'		=> 'La',

		'January'	=> 'Tammikuu',
		'February'	=> 'Helmikuu',
		'March'		=> 'Maaliskuu',
		'April'		=> 'Huhtikuu',
		'May'		=> 'Toukokuu',
		'June'		=> 'Kesäkuu',
		'July'		=> 'Heinäkuu',
		'August'	=> 'Elokuu',
		'September' => 'Syyskuu',
		'October'	=> 'Lokakuu',
		'November'	=> 'Marraskuu',
		'December'	=> 'Joulukuu',

		'Jan'		=> 'Tammi',
		'Feb'		=> 'Helmi',
		'Mar'		=> 'Maalis',
		'Apr'		=> 'Huhti',
		'May_short'	=> 'Touko', //May_short ei koske suomea
		'Jun'		=> 'Kesä',
		'Jul'		=> 'Heinä',
		'Aug'		=> 'Elo',
		'Sep'		=> 'Syys',
		'Oct'		=> 'Loka',
		'Nov'		=> 'Marras',
		'Dec'		=> 'Joulu',
	),

	'tz'				=> array(
		'-12'	=> 'UTC - 12 tuntia',
		'-11'	=> 'UTC - 11 tuntia',
		'-10'	=> 'UTC - 10 tuntia',
		'-9.5'	=> 'UTC - 9:30 tuntia',
		'-9'	=> 'UTC - 9 tuntia',
		'-8'	=> 'UTC - 8 tuntia',
		'-7'	=> 'UTC - 7 tuntia',
		'-6'	=> 'UTC - 6 tuntia',
		'-5'	=> 'UTC - 5 tuntia',
        '-4.5'   => 'UTC - 4:30 tuntia',
		'-4'	=> 'UTC - 4 tuntia',
		'-3.5'	=> 'UTC - 3:30 tuntia',
		'-3'	=> 'UTC - 3 tuntia',
		'-2'	=> 'UTC - 2 tuntia',
		'-1'	=> 'UTC - 1 tunti',
		'0'		=> 'UTC',
		'1'		=> 'UTC + 1 tunti',
		'2'		=> 'UTC + 2 tuntia',
		'3'		=> 'UTC + 3 tuntia',
		'3.5'	=> 'UTC + 3:30 tuntia',
		'4'		=> 'UTC + 4 tuntia',
		'4.5'	=> 'UTC + 4:30 tuntia',
		'5'		=> 'UTC + 5 tuntia',
		'5.5'	=> 'UTC + 5:30 tuntia',
		'5.75'	=> 'UTC + 5:45 tuntia',
		'6'		=> 'UTC + 6 tuntia',
		'6.5'	=> 'UTC + 6:30 tuntia',
		'7'		=> 'UTC + 7 tuntia',
		'8'		=> 'UTC + 8 tuntia',
		'8.75'	=> 'UTC + 8:45 tuntia',
		'9'		=> 'UTC + 9 tuntia',
		'9.5'	=> 'UTC + 9:30 tuntia',
		'10'	=> 'UTC + 10 tuntia',
		'10.5'	=> 'UTC + 10:30 tuntia',
		'11'	=> 'UTC + 11 tuntia',
		'11.5'	=> 'UTC + 11:30 tuntia',
		'12'	=> 'UTC + 12 tuntia',
		'12.75'	=> 'UTC + 12:45 tuntia',
		'13'	=> 'UTC + 13 tuntia',
		'14'	=> 'UTC + 14 tuntia',
		'dst'	=> '[ <abbr title="Kesäaika">DST</abbr> ]',
	),

	'tz_zones'	=> array(
		'-12'	=> '[UTC - 12] Bakersaarten aika',
		'-11'	=> '[UTC - 11] Niuen aika, Samoan normaaliaika',
		'-10'	=> '[UTC - 10] Havaijin-Aleuttien normaaliaika, Cooksaarten aika',
		'-9.5'	=> '[UTC - 9:30] Marquesassaarten aika',
		'-9'	=> '[UTC - 9] Alaskan normaaliaika, Gambiersaarten aika',
		'-8'	=> '[UTC - 8] Tyynenmeren normaaliaika',
		'-7'	=> '[UTC - 7] Kalliovuorten normaaliaika',
		'-6'	=> '[UTC - 6] Keskinen normaaliaika',
		'-5'	=> '[UTC - 5] Itäinen normaaliaika',
        '-4.5'   => '[UTC - 4:30] Venezuelan normaaliaika',
		'-4'	=> '[UTC - 4] Atlantin normaaliaika',
		'-3.5'	=> '[UTC - 3:30] Newfoundlandin normaaliaika',
		'-3'	=> '[UTC - 3] Amazonin normaaliaika, Keski-Grönlannin aika',
		'-2'	=> '[UTC - 2] Fernando de Noronhan aika, Etelä-Georgian ja Eteläisten Sandwichsaarten aika',
		'-1'	=> '[UTC - 1] Azorien normaaliaika, Kap Verden aika, Itä-Grönlannin aika',
		'0'		=> '[UTC] Länsi-Euroopan aika, Greenwichin aika',
		'1'		=> '[UTC + 1] Keski-Euroopan aika, Länsi-Afrikan aika',
		'2'		=> '[UTC + 2] Itä-Euroopan, Keski-Afrikan aika',
		'3'		=> '[UTC + 3] Moskovan normaaliaika, Itä-Afrikan aika',
		'3.5'	=> '[UTC + 3:30] Iranin normaaliaika',
		'4'		=> '[UTC + 4] Persianlahden normaaliaika, Samaran normaaliaika',
		'4.5'	=> '[UTC + 4:30] Afganistanin aika',
		'5'		=> '[UTC + 5] Pakistanin normaaliaika, Jekaterinburgin normaaliaika',
		'5.5'	=> '[UTC + 5:30] Intian normaaliaika, Sri Lankan aika',
		'5.75'	=> '[UTC + 5:45] Nepalin aika',
		'6'		=> '[UTC + 6] Bangladeshin aika, Bhutanin aika, Novosibirskin normaaliaika',
		'6.5'	=> '[UTC + 6:30] Kookossaarten aika, Myanmarin aika',
		'7'		=> '[UTC + 7] Indokiinan aika, Krasnojarskin normaaliaika',
		'8'		=> '[UTC + 8] Kiinan normaaliaika, Länsi-Australian normaaliaika, Irkutskin normaaliaika',
		'8.75'	=> '[UTC + 8:45] Kaakkois-Länsi-Australian normaaliaika',
		'9'		=> '[UTC + 9] Japanin normaaliaika, Korean normaaliaika, Chitan normaaliaika',
		'9.5'	=> '[UTC + 9:30] Keski-Australian normaaliaika',
		'10'	=> '[UTC + 10] Itä-Australian normaaliaika, Vladivostokin normaaliaika',
		'10.5'	=> '[UTC + 10:30] Lord Howen normaaliaika',
		'11'	=> '[UTC + 11] Salomonsaarten aika, Magadan Standard Aika',
		'11.5'	=> '[UTC + 11:30] Norfolkinsaaren aika',
		'12'	=> '[UTC + 12] Uuden-Seelannin aika, Fidžin aika, Kamtšatkan normaaliaika',
		'12.75'	=> '[UTC + 12:45] Chathamsaarten aika',
		'13'	=> '[UTC + 13] Tongan aika, Phoenixsaarten aika',
		'14'	=> '[UTC + 14] Linesaarten aika',
	),

	// The value is only an example and will get replaced by the current time on view
	'dateformats'	=> array(
		'd M Y, H:i'			=> '01 Tammi 2007, 13:37',
		'd M Y H:i'				=> '01 Tammi 2007 13:37',
		'M jS, \'y, H:i'		=> 'Tammi 1, \'07, 13:37',
		'D M d, Y g:i a'		=> 'Ma Tammi 01, 2007 1:37 pm',
		'F jS, Y, g:i a'		=> 'Tammikuun 1 päivä, 2007, 1:37 pm',
		'|d M Y|, H:i'			=> 'Tänään, 13:37 / 01 Tammi 2007, 13:37',
		'|F jS, Y|, g:i a'		=> 'Tänään, 1:37 pm / Tammikuun 1 päivä, 2007, 1:37 pm'
	),

	// The default dateformat which will be used on new installs in this language
	// Translators should change this if a the usual date format is different
	'default_dateformat'	=> 'd.m.Y H:i',

));

?>